@@ -1,15 +1,13 @@
-use std::{borrow::Cow, sync::Arc};
-
-use crate::KV;
+use std::{borrow::Cow, collections::HashMap};
 
 pub trait Forward {
     fn get_persistent<K: AsRef<str>>(&self, key: K) -> Option<&str>;
     fn get_transient<K: AsRef<str>>(&self, key: K) -> Option<&str>;
     fn get_upstream<K: AsRef<str>>(&self, key: K) -> Option<&str>;
 
-    fn get_all_persistents(&self) -> Option<&Vec<Arc<KV>>>;
-    fn get_all_transients(&self) -> Option<&Vec<Arc<KV>>>;
-    fn get_all_upstreams(&self) -> Option<&Vec<Arc<KV>>>;
+    fn get_all_persistents(&self) -> Option<&HashMap<Cow<'static, str>, Cow<'static, str>>>;
+    fn get_all_transients(&self) -> Option<&HashMap<Cow<'static, str>, Cow<'static, str>>>;
+    fn get_all_upstreams(&self) -> Option<&HashMap<Cow<'static, str>, Cow<'static, str>>>;
 
     fn set_persistent<K: Into<Cow<'static, str>>, V: Into<Cow<'static, str>>>(
         &mut self,
